(*****************************************************************************)
(* MODULE: IPQuery                                                           *)
(* AUTHOR: Thomas Werner                                                     *)
(* RIGHTS: (C) Component Store Ltd. 1998                                     *)
(* DESCR.: This module contains classes for InfoPower compatibility          *)
(*         for SQLQuery                                                      *)
(*****************************************************************************)

Unit ipquery;

interface

uses
  SysUtils,
  WinTypes,
  WinProcs,
  Messages,
  Classes,
  Graphics,
  Controls,
  Forms,
  DB,
  dialogs,
  wwfilter,
  wwStr,
  wwSystem,
  wwTable,
  wwtypes,
  SQLServer;  {Add your dataset's unit here}

Type
  TwwSQLQuery =
  Class( TSQLQuery )    {Change to derive from your dataset type}
    Private
      FControlType    : TStrings;
      FPictureMasks   : TStrings;
      FUsePictureMask : boolean;
      FOnInvalidValue : TwwInvalidValueEvent;

      Function GetControlType : TStrings;
      Procedure SetControlType( sel : TStrings );
      Function GetPictureMasks : TStrings;
      Procedure SetPictureMasks( sel : TStrings );

    Protected
      Procedure DoBeforePost; Override; { For picture support }

    Public
      Constructor Create( AOwner : TComponent ); Override;
      Destructor Destroy; Override;

    Published
				  {$ifdef ver100}
    //  Property IndexDefs;  // Only Publish this if your component defines IndexDefs
						{$endif}
      Property ControlType : TStrings
        Read  GetControlType
        Write setControltype;
      Property PictureMasks: TStrings
        Read GetPictureMasks
        Write SetPictureMasks;
      Property ValidateWithMask : boolean
        Read FUsePictureMask
        Write FUsePictureMask;
      Property OnInvalidValue: TwwInvalidValueEvent
        Read FOnInvalidValue
        Write FOnInvalidValue;
  end;

Procedure Register;

implementation
uses
  wwcommon,
  dbconsts;


Constructor TwwSQLQuery.create( AOwner : TComponent );
begin
  inherited Create( AOwner );
  FControlType    := TStringList.create;
  FPictureMasks   := TStringList.create;
  FUsePictureMask := True;
end;


Destructor TwwSQLQuery.Destroy;
begin
  FControlType.Free;
  FPictureMasks.Free;
  FPictureMasks:= NIL;
  Inherited Destroy;
end;


Function TwwSQLQuery.GetControltype : TStrings;
begin
  Result := FControlType;
end;


Procedure TwwSQLQuery.SetControlType( sel : TStrings );
begin
  FControlType.Assign( sel );
end;


Function TwwSQLQuery.GetPictureMasks : TStrings;
begin
  Result:= FPictureMasks
end;


Procedure TwwSQLQuery.SetPictureMasks( sel : TStrings );
begin
  FPictureMasks.Assign( sel );
end;

Procedure TwwSQLQuery.DoBeforePost;
begin
  Inherited DoBeforePost;
  if FUsePictureMask then
    wwValidatePictureFields( self, FOnInvalidValue );
end;

Procedure Register;
begin
  RegisterComponents('IP Access', [TwwSQLQuery] );
end;

end.
